Module: EbDeployer
- Defined in:
- lib/eb_deployer.rb,
lib/eb_deployer/package.rb,
lib/eb_deployer/version.rb,
lib/eb_deployer/beanstalk.rb,
lib/eb_deployer/s3_driver.rb,
lib/eb_deployer/smoke_test.rb,
lib/eb_deployer/application.rb,
lib/eb_deployer/environment.rb,
lib/eb_deployer/event_poller.rb,
lib/eb_deployer/config_loader.rb,
lib/eb_deployer/default_config.rb,
lib/eb_deployer/version_cleaner.rb,
lib/eb_deployer/deployment_strategy.rb,
lib/eb_deployer/cloud_formation_driver.rb,
lib/eb_deployer/cloud_formation_provisioner.rb
Defined Under Namespace
Modules: DeploymentStrategy Classes: Application, Beanstalk, CloudFormationDriver, CloudFormationProvisioner, ConfigLoader, DefaultConfig, Environment, EventPoller, Package, ResourceNotInReadyState, S3Driver, SmokeTest, VersionCleaner
Constant Summary collapse
- TIERS =
[ {:name=>"Worker", :type=>"SQS/HTTP", :version=>"1.0"}, {:name=>"WebServer", :type=>"Standard", :version=>"1.0"} ]
- VERSION =
"0.3.6"
Class Method Summary collapse
- .cli ⇒ Object
-
.deploy(opts) ⇒ Object
Deploy a package to specfied environments on elastic beanstalk.
- .destroy(opts) ⇒ Object
- .environment_tier(name) ⇒ Object
-
.query_resource_output(key, opts) ⇒ Object
Query ouput value of the cloud formation stack.
Class Method Details
.cli ⇒ Object
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/eb_deployer.rb', line 237 def self.cli = { :action => :deploy, :environment => 'dev', :config_file => 'config/eb_deployer.yml' } parser = cli_parser() parser.parse! action = .delete(:action) raise "--all is only valid with --destroy" if ([:all_envs] && action != :destroy) if File.exists?([:config_file]) puts "Found configuration at #{options[:config_file]}." else puts "Generated default configuration at #{options[:config_file]}." DefaultConfig.new(File.basename(Dir.pwd)).write_to([:config_file]) exit(2) end if ![:package] && action == :deploy puts "Missing options: -p (--package)" puts "'eb_deploy --help' for details" puts parser exit(-1) end self.send(action, ConfigLoader.new.load()) end |
.deploy(opts) ⇒ Object
Deploy a package to specfied environments on elastic beanstalk
packages will be stored. Note that the string ".packages" will be added as a suffix to your bucket. So, if "thoughtworks.simple" is passed as the bucket name, the actual s3 bucket name will be thoughtworks.simple.packages.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/eb_deployer.rb', line 175 def self.deploy(opts) if region = opts[:region] AWS.config(:region => region) end bs = opts[:bs_driver] || Beanstalk.new s3 = opts[:s3_driver] || S3Driver.new cf = opts[:cf_driver] || CloudFormationDriver.new stack_name = opts[:solution_stack_name] || "64bit Amazon Linux 2013.09 running Tomcat 7 Java 7" app = opts[:application] env_name = opts[:environment] version_prefix = opts[:version_prefix].to_s.strip version_label = "#{version_prefix}#{opts[:version_label].to_s.strip}" cname = opts[:cname] env_settings = opts[:option_settings] || opts[:settings] || [] strategy_name = opts[:strategy] || :blue_green cname_prefix = opts[:cname_prefix] || [app, env_name].join('-') smoke_test = opts[:smoke_test] || Proc.new {} phoenix_mode = opts[:phoenix_mode] bucket = opts[:package_bucket] || app skip_resource = opts[:skip_resource_stack_update] keep_latest = opts[:keep_latest].to_i || 0 app_tier = self.environment_tier(opts[:tier] || 'WebServer') application = Application.new(app, bs, s3, bucket) cf = CloudFormationProvisioner.new("#{app}-#{env_name}", cf) creation_opts = { :solution_stack => stack_name, :cname_prefix => cname_prefix, :smoke_test => smoke_test, :phoenix_mode => phoenix_mode, :tier => app_tier } strategy = DeploymentStrategy.create(strategy_name, app, env_name, bs, creation_opts) cleaner = VersionCleaner.new(application, keep_latest) if resources = opts[:resources] cf.provision(resources) unless skip_resource env_settings += cf.transform_outputs(resources) end application.create_version(version_label, opts[:package]) strategy.deploy(version_label, env_settings) cleaner.clean(version_prefix) end |
.destroy(opts) ⇒ Object
225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/eb_deployer.rb', line 225 def self.destroy(opts) if region = opts[:region] AWS.config(:region => region) end app = opts[:application] bs = opts[:bs_driver] || Beanstalk.new s3 = opts[:s3_driver] || S3Driver.new cf = opts[:cf_driver] || CloudFormationDriver.new Application.new(app, bs, s3).delete(opts[:environment]) end |
.environment_tier(name) ⇒ Object
32 33 34 |
# File 'lib/eb_deployer.rb', line 32 def environment_tier(name) TIERS.find {|t| t[:name].downcase == name.downcase} || raise("No tier found with name #{name.inspect}") end |
.query_resource_output(key, opts) ⇒ Object
Query ouput value of the cloud formation stack
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/eb_deployer.rb', line 45 def self.query_resource_output(key, opts) if region = opts[:region] AWS.config(:region => region) end app = opts[:application] env_name = opts[:environment] cf = opts[:cf_driver] || CloudFormationDriver.new provisioner = CloudFormationProvisioner.new("#{app}-#{env_name}", cf) provisioner.output(key) end |