Module: EbDeployer

Defined in:
lib/eb_deployer.rb,
lib/eb_deployer/package.rb,
lib/eb_deployer/version.rb,
lib/eb_deployer/beanstalk.rb,
lib/eb_deployer/s3_driver.rb,
lib/eb_deployer/smoke_test.rb,
lib/eb_deployer/application.rb,
lib/eb_deployer/environment.rb,
lib/eb_deployer/event_poller.rb,
lib/eb_deployer/config_loader.rb,
lib/eb_deployer/default_config.rb,
lib/eb_deployer/deployment_strategy.rb,
lib/eb_deployer/cloud_formation_driver.rb,
lib/eb_deployer/cloud_formation_provisioner.rb

Defined Under Namespace

Modules: DeploymentStrategy Classes: Application, Beanstalk, CloudFormationDriver, CloudFormationProvisioner, ConfigLoader, DefaultConfig, Environment, EventPoller, Package, ResourceNotInReadyState, S3Driver, SmokeTest

Constant Summary collapse

VERSION =
"0.2.6"

Class Method Summary collapse

Class Method Details

.cliObject



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/eb_deployer.rb', line 206

def self.cli
  options = {
    :action => :deploy,
    :environment => 'dev',
    :config_file => 'config/eb_deployer.yml'
  }

  parser = cli_parser(options)
  parser.parse!
  action = options.delete(:action)

  unless File.exists?(options[:config_file])
    puts "Generated default configuration at #{options[:config_file]}."
    DefaultConfig.new(File.basename(Dir.pwd)).write_to(options[:config_file])
    exit(2)
  end

  if !options[:package] && action == :deploy
    puts "Missing options: -p (--package)"
    puts parser
    exit(-1)
  end


  self.send(action, ConfigLoader.new.load(options))
end

.deploy(opts) ⇒ Object

Deploy a package to specfied environments on elastic beanstalk

packages will be stored. Note that the string ".packages" will be added as a suffix to your bucket. So, if "thoughtworks.simple" is passed as the bucket name, the actual s3 bucket name will be thoughtworks.simple.packages.

Parameters:

  • opts (Hash)

Options Hash (opts):

  • :application (Symbol)

    required Application name, this used for isolate packages and contribute to your elastic beanstalk cname for environments

  • :environment (Symbol)

    required Environment for same application, e.g. testing, staging, production. This will map to 2 elastic beanstalk environments (env-a-xxx, env-b-xxx) if blue-green deployment strategy specified

  • :package (Symbol)

    required package for the application which should be suitable for elastic beanstalk deploying. For example, a war file should be provided for java solution stacks and a ZIP file should be provided for Rails or Sinatra stack.

  • :option_settings (Symbol) — default: optional

    Elastic Beanstalk settings that will apply to the environments you deploying. Value should be array of hash with format such as:

    [{
     :namespace => 'aws:autoscaling:launchconfiguration',
     :option_name => 'InstanceType',
     :value => 'm1.small' }]
    

    When there are many, Using an external yaml file to hold those configuration is recommended. Such as:

    YAML.load(File.read("my_settings_file.yml"))
    

    For all available options take a look at http://docs.aws.amazon.com/elasticbeanstalk/latest/dg/command-options.html

  • :phoenix_mode (Symbol) — default: false

    If phoenix mode is turn on, it will terminate the old elastic beanstalk environment and recreate on deploy. For blue-green deployment it terminate the inactive environment first then recreate it. This is useful to avoiding configuration drift and accumulating state on the EC2 instances. Also it has the benifit of keeping your EC2 instance system package upto date, because everytime EC2 instance boot up from AMI it does a system update.

  • :region (Symbol)

    set the region for application deployment (e.g. "us-west-2", "us-east-1"). See available zones at http://aws.amazon.com/elasticbeanstalk/faqs/#regions

  • :resources (Symbol)

    If :resources specified, EBDeployer will use the CloudFormation template you provide to create a default CloudFormation stack with name <application_name>- for the environment current deploying. Value of resources need to be hash with following keys:

    :template => CloudFormation template file with JSON format
    :parameters (or :inputs) => A Hash, input values for the CloudFormation template
    :transforms => A Hash with key map to your CloudFormation
    

    template outputs and value as lambda that return a single or array of elastic beanstalk settings.

    :capabilities => An array. You need set it to ['CAPABILITY_IAM']
    

    if you want to provision IAM Instance Profile.

  • :settings (Symbol)

    See option_settings

  • :package_bucket (Symbol)

    Name of s3 bucket where uploaded application

  • :smoke_test (Symbol)

    Value should be a proc or a lambda which accept single argument that will passed in as environment DNS name. Smoke test proc or lambda will be called at the end of the deployment for inplace-update deployment strategy. For blue-green deployment it will run after inactive environment update finish and before switching. Defining a smoke test is high recommended for serious usage. The simplest one could just be checking the server is up using curl, e.g.

    :smoke_test => lambda { |host|
    curl_http_code = "curl -k -s -o /dev/null -w \"%{http_code}\" https://#{host}"
    Timeout.timeout(600) do
      while `#{curl_http_code}`.strip != '200'
        sleep 5
      end
    end
    }
  • :strategy (Symbol) — default: :blue-green

    There are two options: blue-green or inplace-update. Blue green keep two elastic beanstalk environments and always deploy to inactive one, to achive zero downtime. inplace-update strategy will only keep one environment, and update the version inplace on deploy. this will save resources but will have downtime.

  • :solution_stack_name (Symbol) — default: "64bit Amazon Linux running Tomcat 7"

    The elastic beanstalk solution stack you want to deploy on top of.

  • :version_label (Symbol)

    required. Version label give the package uploaded a unique identifier. Should use something related to pipeline counter if you have build pipeline setup to build the installer. For the convient of dev we recommend use md5 digest of the installer so that everytime you upload new installer it forms a new version. e.g.

    :version_label => ENV['MY_PIPELINE_COUNTER']
                    || "dev-" + Digest::MD5.file(my_package).hexdigest


155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/eb_deployer.rb', line 155

def self.deploy(opts)
  # AWS.config(:logger => Logger.new($stdout))
  if region = opts[:region]
    AWS.config(:region => region)
  end

  bs = opts[:bs_driver] || Beanstalk.new
  s3 = opts[:s3_driver] || S3Driver.new
  cf = opts[:cf_driver] || CloudFormationDriver.new
  stack_name = opts[:solution_stack_name] || "64bit Amazon Linux running Tomcat 7"
  app = opts[:application]
  env_name = opts[:environment]
  version_label = opts[:version_label].to_s.strip
  cname = opts[:cname]
  env_settings = opts[:option_settings] || opts[:settings] || []
  strategy_name = opts[:strategy] || :blue_green
  cname_prefix = opts[:cname_prefix] || [app, env_name].join('-')
  smoke_test = opts[:smoke_test] || Proc.new {}
  phoenix_mode = opts[:phoenix_mode]
  bucket = opts[:package_bucket] || app

  application = Application.new(app, bs, s3, bucket)

  cf = CloudFormationProvisioner.new("#{app}-#{env_name}", cf)

  strategy = DeploymentStrategy.create(strategy_name, app, env_name, bs,
                                       :solution_stack => stack_name,
                                       :cname_prefix => cname_prefix,
                                       :smoke_test => smoke_test,
                                       :phoenix_mode => phoenix_mode)

  if resources = opts[:resources]
    env_settings += cf.provision(resources)
  end

  application.create_version(version_label, opts[:package])
  strategy.deploy(version_label, env_settings)
end

.destroy(opts) ⇒ Object



194
195
196
197
198
199
200
201
202
203
204
# File 'lib/eb_deployer.rb', line 194

def self.destroy(opts)
  if region = opts[:region]
    AWS.config(:region => region)
  end

  app = opts[:application]
  bs = opts[:bs_driver] || Beanstalk.new
  s3 = opts[:s3_driver] || S3Driver.new
  cf = opts[:cf_driver] || CloudFormationDriver.new
  Application.new(app, bs, s3).delete
end

.query_resource_output(key, opts) ⇒ Object

Query ouput value of the cloud formation stack

Parameters:

  • key (String)

    CloudFormation output key

  • opts (Hash)

Options Hash (opts):

  • :application (Symbol)

    application name

  • :environment (Symbol)

    environment name (e.g. staging, production)

  • :region (Symbol)

    AWS Region (e.g. "us-west-2", "us-east-1")



35
36
37
38
39
40
41
42
43
44
45
# File 'lib/eb_deployer.rb', line 35

def self.query_resource_output(key, opts)
  # AWS.config(:logger => Logger.new($stdout))
  if region = opts[:region]
    AWS.config(:region => region)
  end
  app = opts[:application]
  env_name = opts[:environment]
  cf = opts[:cf_driver] || CloudFormationDriver.new
  provisioner = CloudFormationProvisioner.new("#{app}-#{env_name}", cf)
  provisioner.output(key)
end